/**
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

import { TestableComponentInterface } from "@wso2is/core/models";
import { Heading, InfoCard, PageLayout } from "@wso2is/react-components";
import React, { FunctionComponent, ReactElement } from "react";
import { useTranslation } from "react-i18next";
import { Card, Grid, Label } from "semantic-ui-react";
import CSSIcon from "../../../assets/images/icons/css-icon.svg";
import LetterTIcon from "../../../assets/images/icons/letter-t.svg";
import LinkIcon from "../../../assets/images/icons/link-icon.svg";
import GalleryIcon from "../../../assets/images/icons/photos-gallery-icon.svg";
import WWWIcon from "../../../assets/images/icons/www-icon.svg";

/**
 * Proptypes for the branding page component.
 */
type BrandingPageInterface = TestableComponentInterface;

/**
 * Branding page.
 *
 * @param {BrandingPageInterface} props - Props injected to the component.
 *
 * @return {React.ReactElement}
 */
const BrandingPage: FunctionComponent<BrandingPageInterface> = (
    props: BrandingPageInterface
): ReactElement => {

    const {
        ["data-testid"]: testId
    } = props;

    const { t } = useTranslation();

    return (
        <PageLayout
            title={ (
                <>
                    { t("extensions:develop.branding.pageHeader.title") }
                    <Label className="coming-soon-label">{ t("common:comingSoon") }</Label>
                </>
            ) }
            description={ t("extensions:develop.branding.pageHeader.description") }
            data-testid={ `${ testId }-layout` }
            className="branding-page"
        >
            <Grid>
                <Grid.Row>
                    <Grid.Column>
                        <Heading as="h3" compact={ true }>See what&apos;s coming</Heading>
                    </Grid.Column>
                </Grid.Row>
                <Grid.Row>
                    <Grid.Column computer={ 8 } tablet={ 16 } mobile={ 16 }>
                        <Card.Group>
                            <InfoCard
                                fluid
                                noHover
                                imageSize="mini"
                                image={ LetterTIcon }
                                header={ "Update the Organization details" }
                                description={
                                    "Change the site title, copyright text & support email shown to your customers."
                                }
                            />
                            <InfoCard
                                fluid
                                noHover
                                imageSize="mini"
                                image={ GalleryIcon }
                                header={ "Customize Images" }
                                description={ "Change the logo and the favicon appearing in the login screens." }
                            />
                            <InfoCard
                                fluid
                                noHover
                                imageSize="mini"
                                image={ LinkIcon }
                                header={ "External Links" }
                                description={ "Modify the privacy policy, terms of service & cookie policy links." }
                            />
                            <InfoCard
                                fluid
                                noHover
                                imageSize="mini"
                                image={ CSSIcon }
                                header={ "Override default styles" }
                                description={ "Provide a CSS stylesheet and override the default Asgardeo styling." }
                            />
                            <InfoCard
                                fluid
                                noHover
                                imageSize="mini"
                                image={ WWWIcon }
                                header={ "Custom Domains" }
                                description={ "Keep your users in the same domain to maintain a consistent UX." }
                            />
                        </Card.Group>
                    </Grid.Column>
                </Grid.Row>
            </Grid>
        </PageLayout>
    );
};

/**
 * Default props for the component.
 */
BrandingPage.defaultProps = {
    "data-testid": "branding-page"
};

/**
 * A default export was added to support React.lazy.
 * TODO: Change this to a named export once react starts supporting named exports for code splitting.
 * @see {@link https://reactjs.org/docs/code-splitting.html#reactlazy}
 */
export default BrandingPage;
